@@ -8,7 +8,7 @@ use base 'Import::Base';
 sub modules {
     strict => [],
     warnings => [],
-    'Module::Runtime' => [qw( use_module )],
+    'Module::Runtime' => [qw( use_module is_module_name check_module_name )],
 }
 
 1;
